==> fheroes2_1.1.12+dfsg.orig.tar.xz: fheroes2-1.1.12+dfsg/src/fheroes2/gui/interface_border.h <==
/***************************************************************************
 *   fheroes2: https://github.com/ihhub/fheroes2                           *
 *   Copyright (C) 2019 - 2025                                             *
 *                                                                         *
 *   Free Heroes2 Engine: http://sourceforge.net/projects/fheroes2         *
 *   Copyright (C) 2009 by Andrey Afletdinov <fheroes2@gmail.com>          *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#pragma once

#include <cstdint>

#include "dialog.h"
#include "math_base.h"

namespace Interface
{
    void GameBorderRedraw( const bool viewWorldMode );

    class BorderWindow
    {
    public:
        explicit BorderWindow( const fheroes2::Rect & rt );
        BorderWindow( const BorderWindow & ) = delete;

        virtual ~BorderWindow() = default;

        BorderWindow & operator=( const BorderWindow & ) = delete;

        virtual void SetPos( int32_t x, int32_t y ) = 0;
        virtual void SavePosition() = 0;

        bool QueueEventProcessing();

        const fheroes2::Rect & GetRect() const;
        const fheroes2::Rect & GetArea() const
        {
            return area;
        }

        // Checks if the mouse is still captured by this UI element. See the implementation for details.
        bool isMouseCaptured();

    protected:
        void Redraw() const;

        void SetPosition( const int32_t x, const int32_t y, const int32_t width, const int32_t height );
        void SetPosition( int32_t x, int32_t y );

        // Captures the mouse by this UI element if necessary. The conditions for capturing imply that
        // the mouse cursor is on this UI element and the left mouse button is pressed.
        void captureMouse();

        fheroes2::Rect area;
        Dialog::FrameBorder border;

        bool _isMouseCaptured{ false };
    };
}

==> fheroes2_1.1.13+dfsg.orig.tar.xz: fheroes2-1.1.13+dfsg/src/fheroes2/gui/interface_border.h <==
/***************************************************************************
 *   fheroes2: https://github.com/ihhub/fheroes2                           *
 *   Copyright (C) 2019 - 2025                                             *
 *                                                                         *
 *   Free Heroes2 Engine: http://sourceforge.net/projects/fheroes2         *
 *   Copyright (C) 2009 by Andrey Afletdinov <fheroes2@gmail.com>          *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#pragma once

#include <cstdint>

#include "dialog.h"
#include "math_base.h"

namespace Interface
{
    void GameBorderRedraw( const bool viewWorldMode );

    class BorderWindow
    {
    public:
        explicit BorderWindow( const fheroes2::Rect & rt )
            : area( rt )
        {
            // Do nothing.
        }

        BorderWindow( const BorderWindow & ) = delete;

        virtual ~BorderWindow() = default;

        BorderWindow & operator=( const BorderWindow & ) = delete;

        virtual void SetPos( int32_t x, int32_t y ) = 0;
        virtual void SavePosition() = 0;

        bool QueueEventProcessing();

        const fheroes2::Rect & GetRect() const;
        const fheroes2::Rect & GetArea() const
        {
            return area;
        }

        // Checks if the mouse is still captured by this UI element. See the implementation for details.
        bool isMouseCaptured();

    protected:
        void Redraw() const;

        void SetPosition( const int32_t x, const int32_t y, const int32_t width, const int32_t height );
        void SetPosition( int32_t x, int32_t y );

        // Captures the mouse by this UI element if necessary. The conditions for capturing imply that
        // the mouse cursor is on this UI element and the left mouse button is pressed.
        void captureMouse();

        fheroes2::Rect area;
        Dialog::FrameBorder border;

        bool _isMouseCaptured{ false };
    };
}
